@@ -26,6 +26,6 @@ class ComputeSIP:
             obj.model['COEF'] = tmp['COEF']
             obj.data['X1'] = self.x1
             obj.data['X2'] = self.x2
-            obj.compute()
+            obj.compute(rescale=False)
             out[i] = obj.model['YFIT']
         self.coef1d = out           
