@@ -287,6 +287,6 @@ class Extract:
 
         fig.tight_layout()
         if save:
-            string = '{0}_spc1d.{1}'.format(newobj.data['objname'],saveformat) if savename_prefix is None else '{0}_spc1d.{1}'.format(savename_prefix,saveformat)
+            string = '{0}_spc1d.{1}'.format(self.data['objname'],saveformat) if savename_prefix is None else '{0}_spc1d.{1}'.format(savename_prefix,saveformat)
             fig.savefig(string,format=saveformat,bbox_inches='tight')
             print('Save {0}'.format(string))
