@@ -9,11 +9,10 @@ import copy
 from .confreader import ConfReader
 from .computesip import ComputeSIP
 from .computetracenwavelength import ComputeTraceNWavelength
-from .flatfield import FlatField
 
 class Wfc3IrG102:
     def __init__(self,objname='None',dfile=None,gfile=None,extnum=4,
-                 conffile=None,flatfile=None,sensfile=None,beam=None,
+                 conffile=None,beam=None,
                  xyd=None
                 ):
         self.data = {'objname':objname,
@@ -21,8 +20,6 @@ class Wfc3IrG102:
                      'gfile':gfile,
                      'extnum':extnum,
                      'conffile':conffile,
-                     'flatfile':flatfile,
-                     'sensfile':sensfile,
                      'beam':beam,
                      'xyd':xyd,
                      'ROOTNAME':None,
@@ -36,8 +33,7 @@ class Wfc3IrG102:
                       'YG':None,
                       'WW':None
                      }
-        self.flatfield = None
-        self.background = None
+        self.tracefile = None
         self._get_root()
         self._get_nax()
         self._get_conf()
@@ -66,17 +62,6 @@ class Wfc3IrG102:
     ##########
     ##########
     ##########
-    def compute_flatfield(self,tracefile=None):
-        flatfield = self.data['flatfile']
-        rootname = self.data['ROOTNAME']
-        if tracefile is None:
-            tracefile = '{0}_trace.csv'.format(rootname)
-        obj = FlatField(flatfile=flatfile,tracefile=tracefile)
-        obj.compute()
-        self.flatfield = obj
-    ##########
-    ##########
-    ##########
     def compute(self):
         xyd = self.data['xyd']
         xydiff = self._compute_xydiff()
@@ -138,6 +123,7 @@ class Wfc3IrG102:
             savename_prefix = rootname
         string = '{0}_trace.csv'.format(savename_prefix)
         pd.DataFrame(tmp).to_csv(string,index=False)
+        self.tracefile = string
         print('Save {0}'.format(string))
     ##########
     ##########
